@@ -127,17 +127,39 @@ class NewContentElementController
                     'items' => [],
                 ];
             } else {
+                // Get default values for the wizard item
+                $defaultValues = (array)($wizardItem['defaultValues'] ?? []);
+
                 // Initialize the view variables for the item
                 $item = [
                     'identifier' => $wizardKey,
                     'icon' => $wizardItem['iconIdentifier'] ?? '',
                     'label' => $wizardItem['title'] ?? '',
                     'description' => $wizardItem['description'] ?? '',
+                    'defaultValues' => $defaultValues,
                 ];
-
-                // Get default values for the wizard item
-                $defaultValues = (array)($wizardItem['defaultValues'] ?? []);
-                if (!$positionSelection) {
+                // If the URL was already created (e.g. via the PSR-14 event) this needs to be
+                // kept and not overwritten
+                if (isset($wizardItem['url'])) {
+                    $item['url'] = $wizardItem['url'];
+                    if ($positionSelection) {
+                        $item['requestType'] = 'ajax';
+                        $item['saveAndClose'] = (bool)($wizardItem['saveAndClose'] ?? false);
+                    }
+                } elseif ($positionSelection) {
+                    $item['url'] = (string)$this->uriBuilder
+                        ->buildUriFromRoute(
+                            'new_content_element_wizard',
+                            [
+                                'action' => 'positionMap',
+                                'id' => $this->id,
+                                'sys_language_uid' => $this->sys_language,
+                                'returnUrl' => $this->returnUrl,
+                            ]
+                        );
+                    $item['requestType'] = 'ajax';
+                    $item['saveAndClose'] = (bool)($wizardItem['saveAndClose'] ?? false);
+                } else {
                     // In case no position has to be selected, we can just add the target
                     if (($wizardItem['saveAndClose'] ?? false)) {
                         // Go to DataHandler directly instead of FormEngine
@@ -169,20 +191,6 @@ class NewContentElementController
                             ],
                         ]);
                     }
-                } else {
-                    $item['url'] = (string)$this->uriBuilder
-                        ->buildUriFromRoute(
-                            'new_content_element_wizard',
-                            [
-                                'action' => 'positionMap',
-                                'id' => $this->id,
-                                'sys_language_uid' => $this->sys_language,
-                                'returnUrl' => $this->returnUrl,
-                            ]
-                        );
-                    $item['requestType'] = 'ajax';
-                    $item['defaultValues'] = $defaultValues;
-                    $item['saveAndClose'] = (bool)($wizardItem['saveAndClose'] ?? false);
                 }
                 $categories[$key]['items'][] = $item;
             }
@@ -242,8 +250,10 @@ class NewContentElementController
         foreach ($wizards as $groupKey => $wizardGroup) {
             $wizards[$groupKey] = $this->prepareDependencyOrdering($wizards[$groupKey], 'before');
             $wizards[$groupKey] = $this->prepareDependencyOrdering($wizards[$groupKey], 'after');
+            $wizards[$groupKey] = $this->prepareDependencyOrdering($wizards[$groupKey], 'contentElementAfter');
         }
-        foreach ($this->dependencyOrderingService->orderByDependencies($wizards) as $groupKey => $wizardGroup) {
+        $orderedWizards = $this->orderWizards($wizards, $this->dependencyOrderingService);
+        foreach ($orderedWizards as $groupKey => $wizardGroup) {
             $groupKey = rtrim($groupKey, '.');
             $groupItems = [];
             $appendWizardElements = $appendWizards[$groupKey . '.']['elements.'] ?? null;
@@ -291,7 +301,17 @@ class NewContentElementController
     {
         $fieldConfig = $GLOBALS['TCA']['tt_content']['columns'][$typeField] ?? [];
         $items = $fieldConfig['config']['items'] ?? [];
+        $itemGroups = $fieldConfig['config']['itemGroups'] ?? [];
         $groupedWizardItems = [];
+        // Auto-set positional information based on TCA itemGroups sorting.
+        $lastGroup = null;
+        foreach (array_keys($itemGroups) as $groupIdentifier) {
+            $groupedWizardItems[$groupIdentifier . '.']['header'] = $itemGroups[$groupIdentifier];
+            if ($lastGroup !== null) {
+                $groupedWizardItems[$groupIdentifier . '.']['contentElementAfter'] = $lastGroup;
+            }
+            $lastGroup = $groupIdentifier;
+        }
         foreach ($items as $item) {
             $selectItem = SelectItem::fromTcaItemArray($item);
             if ($selectItem->isDivider()) {
@@ -299,12 +319,9 @@ class NewContentElementController
             }
             $recordType = $selectItem->getValue();
             $groupIdentifier = $selectItem->getGroup();
-            if (!is_array($groupedWizardItems[$groupIdentifier . '.'] ?? null)) {
-                $groupedWizardItems[$groupIdentifier . '.'] = [
-                    'elements.' => [],
-                    'header' => $fieldConfig['config']['itemGroups'][$groupIdentifier] ?? $groupIdentifier,
-                ];
-            }
+            $groupedWizardItems[$groupIdentifier . '.']['elements.'] ??= [];
+            // In case this group is not defined in itemGroups, use the group identifier as label.
+            $groupedWizardItems[$groupIdentifier . '.']['header'] ??= $groupIdentifier;
             $itemDescription = $selectItem->getDescription();
             $wizardEntry = [
                 'iconIdentifier' => $selectItem->getIcon(),
@@ -379,6 +396,55 @@ class NewContentElementController
         return $contentElementWizards;
     }
 
+    /*
+     * There are two separate ordering systems for wizard groups:
+     * 1. TCA itemGroup sorting by associative array item order.
+     * 2. PageTS defined order by "before" and "after".
+     *
+     * System 1. has a well-defined order, where every item defines "after" (linked list).
+     * Due to this, the two system cannot be combined.
+     * As soon as system 2 defines at least one "before" or "after" it takes over.
+     */
+    protected function orderWizards(array $wizards, DependencyOrderingService $dependencyOrderingService): array
+    {
+        // First round: Order by TCA defined sorting.
+        $hasAtLeastOnePositionalArgument = false;
+        foreach ($wizards as $group => $wizard) {
+            if (isset($wizard['before'])) {
+                $hasAtLeastOnePositionalArgument = true;
+                $wizards[$group]['pageTsBefore'] = $wizard['before'];
+                unset($wizards[$group]['before']);
+            }
+            if (isset($wizard['after'])) {
+                $hasAtLeastOnePositionalArgument = true;
+                $wizards[$group]['pageTsAfter'] = $wizard['after'];
+                unset($wizards[$group]['after']);
+            }
+            if (isset($wizard['contentElementAfter'])) {
+                $wizards[$group]['after'] = $wizard['contentElementAfter'];
+                unset($wizards[$group]['contentElementAfter']);
+            }
+        }
+        // No order defined by pageTS. Use TCA sorting.
+        if (!$hasAtLeastOnePositionalArgument) {
+            return $dependencyOrderingService->orderByDependencies($wizards);
+        }
+        // Override order by pageTsConfig.
+        foreach ($wizards as $group => $wizard) {
+            // Unset "after" previously set by Content Element wizards.
+            unset($wizards[$group]['after']);
+            if (isset($wizard['pageTsBefore'])) {
+                $wizards[$group]['before'] = $wizard['pageTsBefore'];
+                unset($wizards[$group]['pageTsBefore']);
+            }
+            if (isset($wizard['pageTsAfter'])) {
+                $wizards[$group]['after'] = $wizard['pageTsAfter'];
+                unset($wizards[$group]['pageTsAfter']);
+            }
+        }
+        return $dependencyOrderingService->orderByDependencies($wizards);
+    }
+
     /**
      * This method returns the wizard items, defined in Page TSconfig for b/w
      * compatibility.
