@@ -10,4 +10,4 @@
  *
  * The TYPO3 project - inspiring people to share!
  */
-import{Tree}from"@typo3/backend/tree/tree.js";export class FileStorageTree extends Tree{constructor(){super(),this.settings.defaultProperties={hasChildren:!1,nameSourceField:"title",type:"sys_file",prefix:"",suffix:"",locked:!1,loaded:!1,overlayIcon:"",selectable:!0,expanded:!1,checked:!1}}getNodeTitle(e){return decodeURIComponent(e.name)}}
\ No newline at end of file
+import{Tree as t}from"@typo3/backend/tree/tree.js";class s extends t{constructor(){super(),this.settings.defaultProperties={hasChildren:!1,nameSourceField:"title",type:"sys_file",prefix:"",suffix:"",locked:!1,loaded:!1,overlayIcon:"",selectable:!0,expanded:!1,checked:!1}}getNodeTitle(e){return decodeURIComponent(e.name)}}export{s as FileStorageTree};
