@@ -35,6 +35,11 @@ final readonly class GroupFieldType extends AbstractFieldType implements Relatio
         return 'group';
     }
 
+    public function isNullable(): false
+    {
+        return false;
+    }
+
     public function getRelations(): array
     {
         return $this->relations;
@@ -44,4 +49,10 @@ final readonly class GroupFieldType extends AbstractFieldType implements Relatio
     {
         return RelationshipType::fromTcaConfiguration($this->configuration);
     }
+
+    public function isSearchable(): false
+    {
+        return false;
+    }
+
 }
