@@ -26,4 +26,18 @@ final readonly class ImageManipulationFieldType extends AbstractFieldType
     {
         return 'imageManipulation';
     }
+
+    public function isSearchable(): false
+    {
+        return false;
+    }
+
+    public function isNullable(): false
+    {
+        return false;
+    }
+    public function hasDefaultValue(): false
+    {
+        return false;
+    }
 }
