@@ -24,12 +24,13 @@ use TYPO3\CMS\Core\TypoScript\AST\Node\RootNode;
  *
  * @internal Internal for now until API stabilized. Use BackendUtility::getPagesTSconfig().
  */
-final class PageTsConfig
+final readonly class PageTsConfig
 {
-    private readonly array $pageTsConfigArray;
+    private array $pageTsConfigArray;
 
     public function __construct(
-        private readonly RootNode $pageTsConfigTree
+        private RootNode $pageTsConfigTree,
+        private array $conditionListWithVerdicts,
     ) {
         $this->pageTsConfigArray = $pageTsConfigTree->toArray();
     }
@@ -43,4 +44,9 @@ final class PageTsConfig
     {
         return $this->pageTsConfigArray;
     }
+
+    public function getConditionListWithVerdicts(): array
+    {
+        return $this->conditionListWithVerdicts;
+    }
 }
